#########
Changelog
#########

.. raw:: html

    <a href='https://ko-fi.com/B0B833SXD' target='_blank'><img height='36'style='border:0px;height:36px;' src='https://cdn.ko-fi.com/cdn/kofi1.png?v=2' border='0' alt='Buy Me a Coffee at ko-fi.com' /></a>

Version 0.1.5
=============

- Add the option to add a constraint on minimum portfolio return.
- Add an example of how to add constraints on portfolio return and risk measures.

Version 0.1.4
=============

- Add Black Litterman with factors in two flavors: Black Litterman Bayesian model and Augmented Black Litterman model.
- Implement factors_views, a function that allows to design views on risk factors for Black Litterman with factors.
- Repair some bugs.

Version 0.1.2
=============

- Add Entropic Drawdown at Risk for Mean Risk Portfolio Optimization and Risk Parity Portfolio Optimization.
- Repair some bugs.

Version 0.1.1
=============

- Repair some bugs in Portfolio related to Semi Variance and UCI.
- Implement an option to annualize returns and risk in plot_frontier, Jupyter Notebook and Excel reports.
- Add examples using Vectorbt for Backtesting and MOSEK for large scale problems.

Version 0.1.0
=============

- Repair some bugs in RiskFunctions.
- Implement the Reports module that helps to build reports on Jupyter Notebook and Excel.
- Implement plot_table, a function that resume some indicators of a portfolio.
- Add Entropic Value at Risk for Mean Risk Portfolio Optimization and Risk Parity Portfolio Optimization.

Version 0.0.7
=============

- Implement normal assumption method to estimate box and elliptical uncertainty sets for Worst Case Optimization.
- Implement elliptical uncertainty sets for covariance matrix.
- Add Ulcer Index for Mean Risk Portfolio Optimization and Risk Parity Portfolio Optimization.
- Implement functions to calculate Ulcer Index.

Version 0.0.6
=============

- Repair some bugs.
- Implement bootstrapping methods to estimate box and elliptical uncertainty sets for Worst Case Optimization.
- Implement Worst Case Mean Variance Portfolio Optimization using box and elliptical uncertainty sets.

Version 0.0.5
=============

- Repair some bugs.
- Implement Risk Parity Portfolio Optimization for 7 convex risk measures.

Version 0.0.4
=============

- Repair some bugs.
- Update to make it compatible with cvxpy >=1.1.0
- Implement Principal Component Regression for loadings matrix estimation.
- Add Akaike information criterion, Schwarz information criterion, R squared and adjusted R squared feature selection criterions in stepwise regression.


Version 0.0.3
=============

- Repair some bugs.
- Implement an option for building constraints common for all assets classes.


Version 0.0.2
=============

- Repair some bugs.


Version 0.0.1
=============

- Implement robust estimates and ewma estimates.
- Implement Black Litterman model and risk factors models.
- Implement mean risk optimization with 10 risk measures.
